Hyper-parameter Optimization
============================
.. autoclass:: pykeen.hpo.HpoPipelineResult
    :members:

.. autofunction:: pykeen.hpo.hpo_pipeline_from_path

.. autofunction:: pykeen.hpo.hpo_pipeline_from_config

.. autofunction:: pykeen.hpo.hpo_pipeline
